==> core-1.17.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ITemplateOptions.java <==
package software.amazon.awscdk.core;

/**
 * CloudFormation template options for a stack.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.6 (build 17f281e)", date = "2019-11-19T17:18:01.088Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ITemplateOptions")
@software.amazon.jsii.Jsii.Proxy(ITemplateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ITemplateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getDescription() {
        return null;
    }

    /**
     * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
     */
    @software.amazon.jsii.Optional
    default void setDescription(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setDescription(java.lang.String)' is not implemented!");
    }

    /**
     * Metadata associated with the CloudFormation template.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * Metadata associated with the CloudFormation template.
     */
    @software.amazon.jsii.Optional
    default void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setMetadata(java.util.Map<java.lang.String, java.lang.Object>)' is not implemented!");
    }

    /**
     * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getTemplateFormatVersion() {
        return null;
    }

    /**
     * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
     */
    @software.amazon.jsii.Optional
    default void setTemplateFormatVersion(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTemplateFormatVersion(java.lang.String)' is not implemented!");
    }

    /**
     * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
     * 
     * @deprecated use `transforms` instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default java.lang.String getTransform() {
        return null;
    }

    /**
     * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
     * 
     * @deprecated use `transforms` instead.
     */
    @software.amazon.jsii.Optional
    default void setTransform(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTransform(java.lang.String)' is not implemented!");
    }

    /**
     * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.List<java.lang.String> getTransforms() {
        return null;
    }

    /**
     * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
     */
    @software.amazon.jsii.Optional
    default void setTransforms(final java.util.List<java.lang.String> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTransforms(java.util.List<java.lang.String>)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.ITemplateOptions {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", value);
        }

        /**
         * Metadata associated with the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return java.util.Collections.unmodifiableMap(this.jsiiGet("metadata", java.util.Map.class));
        }

        /**
         * Metadata associated with the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this.jsiiSet("metadata", value);
        }

        /**
         * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getTemplateFormatVersion() {
            return this.jsiiGet("templateFormatVersion", java.lang.String.class);
        }

        /**
         * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setTemplateFormatVersion(final java.lang.String value) {
            this.jsiiSet("templateFormatVersion", value);
        }

        /**
         * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
         * 
         * @deprecated use `transforms` instead.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public java.lang.String getTransform() {
            return this.jsiiGet("transform", java.lang.String.class);
        }

        /**
         * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
         * 
         * @deprecated use `transforms` instead.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public void setTransform(final java.lang.String value) {
            this.jsiiSet("transform", value);
        }

        /**
         * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.List<java.lang.String> getTransforms() {
            return java.util.Collections.unmodifiableList(this.jsiiGet("transforms", java.util.List.class));
        }

        /**
         * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setTransforms(final java.util.List<java.lang.String> value) {
            this.jsiiSet("transforms", value);
        }
    }
}

==> core-1.17.1.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ITemplateOptions.java <==
package software.amazon.awscdk.core;

/**
 * CloudFormation template options for a stack.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.7 (build e0b2c0d)", date = "2019-11-19T21:07:05.749Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ITemplateOptions")
@software.amazon.jsii.Jsii.Proxy(ITemplateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ITemplateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getDescription() {
        return null;
    }

    /**
     * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
     */
    @software.amazon.jsii.Optional
    default void setDescription(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setDescription(java.lang.String)' is not implemented!");
    }

    /**
     * Metadata associated with the CloudFormation template.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * Metadata associated with the CloudFormation template.
     */
    @software.amazon.jsii.Optional
    default void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setMetadata(java.util.Map<java.lang.String, java.lang.Object>)' is not implemented!");
    }

    /**
     * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getTemplateFormatVersion() {
        return null;
    }

    /**
     * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
     */
    @software.amazon.jsii.Optional
    default void setTemplateFormatVersion(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTemplateFormatVersion(java.lang.String)' is not implemented!");
    }

    /**
     * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
     * 
     * @deprecated use `transforms` instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default java.lang.String getTransform() {
        return null;
    }

    /**
     * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
     * 
     * @deprecated use `transforms` instead.
     */
    @software.amazon.jsii.Optional
    default void setTransform(final java.lang.String value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTransform(java.lang.String)' is not implemented!");
    }

    /**
     * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.util.List<java.lang.String> getTransforms() {
        return null;
    }

    /**
     * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
     */
    @software.amazon.jsii.Optional
    default void setTransforms(final java.util.List<java.lang.String> value) {
        throw new UnsupportedOperationException("'void " + getClass().getCanonicalName() + "#setTransforms(java.util.List<java.lang.String>)' is not implemented!");
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.ITemplateOptions {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * Gets or sets the description of this stack. If provided, it will be included in the CloudFormation template's "Description" attribute.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", value);
        }

        /**
         * Metadata associated with the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return java.util.Optional.ofNullable((java.util.Map<java.lang.String, java.lang.Object>)(this.jsiiGet("metadata", java.util.Map.class))).map(java.util.Collections::unmodifiableMap).orElse(null);
        }

        /**
         * Metadata associated with the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setMetadata(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this.jsiiSet("metadata", value);
        }

        /**
         * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getTemplateFormatVersion() {
            return this.jsiiGet("templateFormatVersion", java.lang.String.class);
        }

        /**
         * Gets or sets the AWSTemplateFormatVersion field of the CloudFormation template.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setTemplateFormatVersion(final java.lang.String value) {
            this.jsiiSet("templateFormatVersion", value);
        }

        /**
         * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
         * 
         * @deprecated use `transforms` instead.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public java.lang.String getTransform() {
            return this.jsiiGet("transform", java.lang.String.class);
        }

        /**
         * Gets or sets the top-level template transform for this stack (e.g. "AWS::Serverless-2016-10-31").
         * 
         * @deprecated use `transforms` instead.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public void setTransform(final java.lang.String value) {
            this.jsiiSet("transform", value);
        }

        /**
         * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.List<java.lang.String> getTransforms() {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(this.jsiiGet("transforms", java.util.List.class))).map(java.util.Collections::unmodifiableList).orElse(null);
        }

        /**
         * Gets or sets the top-level template transform(s) for this stack (e.g. `["AWS::Serverless-2016-10-31"]`).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public void setTransforms(final java.util.List<java.lang.String> value) {
            this.jsiiSet("transforms", value);
        }
    }
}
